Creates a preformatted citation for R or an R package. This
function is normally used within an R Markdown or Quarto document, where
pkrt() automatically references the cited package to the first (by
default) .bib file specified in the YAML header if no reference for the
package already exists.