This function lets you configure pakret's settings, for example,
to customize citation templates or specify which .bib file should store
the references.
Details
Valid parameters are:
bib
<character|numeric> = 1L
Name or index of the.bibfile to save references to.pkg
<character> = "the ':pkg' package version :ver [:ref]"
Template used to cite a package.pkg_list
<character> = "':pkg' v. :ver [:ref]"
Template used inpkrt_list().r
<character> = "R version :ver [:ref]"
Template used to cite R.sep
<character> = ", "
Separator used between packages in inline chunks.sep_last
<character> = ", and "
Separator used between the last two packages in inline chunks.
New settings only apply to citations that come after pkrt_set(). This means
you can redefine the same settings multiple times in the same document to
alter pakret's behavior for a few specific citations only.
Use NULL to reset a parameter to its default value.